#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
test_m3u_dump
----------------------------------

Tests for `m3u_dump` module.
"""
import os

import pytest

from click.testing import CliRunner

from m3u_dump import cli
from m3u_dump.m3u_dump import M3uDump


@pytest.fixture(scope='session')
def music_dir(tmpdir_factory):
    return tmpdir_factory.mktemp('music')


@pytest.fixture(scope='session')
def music_files(music_dir):
    d = music_dir
    d.join('dummy001.mp3').write('dummy')
    d.mkdir('sub').join('dummy002.mp3').write('dummy')
    d.mkdir('sub4').join('dummy002.mp3').write('dummy')
    d.mkdir('sub2').mkdir('sub3').join('あいう えお.mp3').write('dummy')
    d.mkdir('sub3').mkdir('かきく　けこ').join('あいう　えお.mp3').write('dummy')
    return d


# noinspection PyShadowingNames
@pytest.fixture(scope='session')
def multi_playlist_music_files(music_dir):
    d = music_dir
    d.join('aaaa.m3u').write('dummy')
    d.mkdir('sub7').join('multi-dummy001.mp3').write('dummy')
    d.mkdir('sub8').mkdir('sub2').join('multi-dummy002.mp3').write('dummy')
    d.mkdir('sub9').join('multi-あいう えお.mp3').write('dummy')
    d.mkdir('sub10').join('multi-あいう　えお.mp3').write('dummy')
    d.mkdir('sub11').join('multi-dummy004.mp3').write('dummy')
    d.mkdir('sub12').join('hello hello.mp3').write('dummy')
    return d


@pytest.fixture
def playlist_dir(tmpdir_factory):
    return tmpdir_factory.mktemp('playlist')


# noinspection PyShadowingNames
@pytest.fixture
def playlist_current(playlist_dir):
    f = playlist_dir.join('playlist.m3u')
    f.write("""#EXTM3U
#EXTINF:409,artist - music_name
/full/path/dummy001.mp3
 #EXTINF:281,artist - music_name
/full/path/dummy002.mp3

#EXTINF:275,artist - music_name
music/あいう えお.mp3
#EXTINF:263,artist - music_name
/full/path/music/あいう　えお.mp3
 #EXTINF:288,artist - music_name
/full/path/aaa/dummy002.mp3
#EXTINF:222,artist = music_name
../../hello.mp3""")
    return f


@pytest.fixture(scope='session')
def already_exists_playlist(tmpdir_factory):
    d = tmpdir_factory.mktemp('already-dir')
    music_path = str(d.mkdir('music').join('already_path.mp3').write('dummy'))
    playlist_content = """#EXTM3U
#EXTINF:409,artist - music_name
{}""".format(os.path.join(str(d), 'music', 'already_path.mp3'))
    playlist_path = str(d.join('playlist.m3u').write(playlist_content))
    return d


# noinspection PyShadowingNames
@pytest.fixture
def playlist_current2(playlist_dir):
    f = playlist_dir.join('playlist2.m3u8')
    f.write("""#EXTM3U
#EXTINF:409,artist - music_name
/full/path/multi-dummy001.mp3
 #EXTINF:282,artist - music_name
/full/path/multi-dummy001.mp3
 #EXTINF:281,artist - music_name
/full/path/multi-dummy002.mp3

#EXTINF:275,artist - music_name
music/multi-あいう えお.mp3
#EXTINF:263,artist - music_name
/full/path/music/multi-あいう　えお.mp3
 #EXTINF:288,artist - music_name
/full/path/aaa/multi-dummy004.mp3
#EXTINF:222,artist = music_name
../../multi-hello.mp3""")
    return f


@pytest.fixture(scope='session')
def dump_music_path(tmpdir_factory):
    d = tmpdir_factory.mktemp('dst')
    return str(d)


def test_command_line_interface():
    runner = CliRunner()
    result = runner.invoke(cli.main)
    assert result.exit_code == 2  # must arguments
    assert 'Error: Missing argument' in result.output
    help_result = runner.invoke(cli.main, ['--help'])
    assert help_result.exit_code == 0
    assert '--help' in help_result.output
    assert 'Show this message and exit.' in help_result.output


# noinspection PyShadowingNames
def test_command_line_dryrun(playlist_current, tmpdir_factory, music_files):
    dst_dir = str(tmpdir_factory.mktemp('no-dump-music'))
    runner = CliRunner()
    result = runner.invoke(cli.main, ['--dry-run', str(playlist_current),
                                      dst_dir, '--fix-search-path',
                                      str(music_files)])
    assert 'Welcome m3u-dump' in result.output
    assert 'copy was completed(successful' in result.output
    assert result.exit_code == 0  # must arguments

    # copy できていないこと
    assert os.path.exists(os.path.join(dst_dir, 'dummy001.mp3')) is False
    assert os.path.exists(os.path.join(dst_dir, 'dummy002.mp3')) is False
    assert os.path.exists(os.path.join(dst_dir, 'あいう えお.mp3')) is False
    assert os.path.exists(os.path.join(dst_dir, 'あいう　えお.mp3')) is False
    assert os.path.exists(os.path.join(dst_dir, 'hello.mp3')) is False

    playlist_name = os.path.basename(str(playlist_current))
    playlist_path = os.path.join(dst_dir, playlist_name)
    assert os.path.exists(playlist_path) is False


# noinspection PyShadowingNames
def test_command_line_start(playlist_current, tmpdir_factory, music_files):
    dst_dir = str(tmpdir_factory.mktemp('dump-music'))
    runner = CliRunner()
    result = runner.invoke(cli.main, [str(playlist_current), dst_dir,
                                      '--fix-search-path', str(music_files)])
    for line in result.output.split('\n'):
        print(line)
    assert 'Welcome m3u-dump' in result.output
    assert 'copy was completed(successful' in result.output
    assert result.exit_code == 0  # must arguments

    # copy できているか確認する
    assert os.path.exists(os.path.join(dst_dir, 'dummy001.mp3')) is True
    assert os.path.exists(os.path.join(dst_dir, 'dummy002.mp3')) is True
    assert os.path.exists(os.path.join(dst_dir, 'あいう えお.mp3')) is True
    assert os.path.exists(os.path.join(dst_dir, 'あいう　えお.mp3')) is True
    assert os.path.exists(os.path.join(dst_dir, 'hello.mp3')) is False

    playlist_name = os.path.basename(str(playlist_current))
    playlist_path = os.path.join(dst_dir, playlist_name)
    assert os.path.exists(playlist_path) is True
    with open(playlist_path, 'r') as f:
        assert '#EXTM3U' == f.readline().rstrip('\n')
        assert '#EXTINF:409,artist - music_name' == f.readline().rstrip('\n')
        assert 'dummy001.mp3' == f.readline().rstrip('\n')
        assert '#EXTINF:281,artist - music_name' == f.readline().rstrip('\n')
        assert 'dummy002.mp3' == f.readline().rstrip('\n')
        assert '#EXTINF:275,artist - music_name' == f.readline().rstrip('\n')
        assert 'あいう えお.mp3' == f.readline().rstrip('\n')
        assert '#EXTINF:263,artist - music_name' == f.readline().rstrip('\n')
        assert 'あいう　えお.mp3' == f.readline().rstrip('\n')
        assert '#EXTINF:288,artist - music_name' == f.readline().rstrip('\n')
        assert 'dummy002.mp3' == f.readline().rstrip('\n')
        assert '' == f.readline().rstrip('\n')


# noinspection PyShadowingNames
def test_command_line_no_fix_start(playlist_current, tmpdir_factory, music_files):
    dst_dir = str(tmpdir_factory.mktemp('dump-music'))
    runner = CliRunner()
    result = runner.invoke(cli.main, [str(playlist_current), dst_dir])
    for line in result.output.split('\n'):
        print(line)
    assert 'Welcome m3u-dump' in result.output
    assert 'copy was completed(successful' in result.output
    assert result.exit_code == 0  # must arguments


# noinspection PyShadowingNames
def test_command_line_already_playlist(already_exists_playlist):
    music_path = os.path.join(str(already_exists_playlist), 'music')
    dst_dir = os.path.join(str(already_exists_playlist), 'dst')
    os.mkdir(dst_dir)
    playlist_path = os.path.join(str(already_exists_playlist), 'playlist.m3u')
    runner = CliRunner()
    result = runner.invoke(cli.main, [playlist_path, dst_dir,
                                      '--fix-search-path', str(music_path)])
    for line in result.output.split('\n'):
        print(line)
    assert 'Welcome m3u-dump' in result.output
    assert 'copy was completed(successful' in result.output
    assert result.exit_code == 0  # must arguments

    # copy できているか確認する
    assert os.path.exists(os.path.join(dst_dir, 'already_path.mp3')) is True

    playlist_path = os.path.join(dst_dir, 'playlist.m3u')
    assert os.path.exists(playlist_path) is True
    with open(playlist_path, 'r') as f:
        assert '#EXTM3U' == f.readline().rstrip('\n')
        assert '#EXTINF:409,artist - music_name' == f.readline().rstrip('\n')
        assert 'already_path.mp3' == f.readline().rstrip('\n')


# noinspection PyShadowingNames
def test_command_line_multi_playlist(playlist_current, playlist_current2,
                                     tmpdir_factory, music_files, multi_playlist_music_files):
    playlist_dir = os.path.dirname(str(playlist_current))
    dst_dir = str(tmpdir_factory.mktemp('dump-music'))
    runner = CliRunner()
    result = runner.invoke(cli.main, [playlist_dir, dst_dir,
                                      '--fix-search-path',
                                      str(music_files)])
    for line in result.output.split('\n'):
        print(line)
    assert 'Welcome m3u-dump' in result.output
    assert 'copy was completed(successful' in result.output
    assert result.exit_code == 0  # must arguments

    # copy できているか確認する
    assert os.path.exists(os.path.join(dst_dir, 'dummy001.mp3')) is True
    assert os.path.exists(os.path.join(dst_dir, 'dummy002.mp3')) is True
    assert os.path.exists(os.path.join(dst_dir, 'あいう えお.mp3')) is True
    assert os.path.exists(os.path.join(dst_dir, 'あいう　えお.mp3')) is True
    assert os.path.exists(os.path.join(dst_dir, 'hello.mp3')) is False

    assert os.path.exists(os.path.join(dst_dir, 'multi-dummy001.mp3')) is True
    assert os.path.exists(os.path.join(dst_dir, 'multi-dummy002.mp3')) is True
    assert os.path.exists(os.path.join(dst_dir, 'multi-あいう えお.mp3')) is True
    assert os.path.exists(os.path.join(dst_dir, 'multi-あいう　えお.mp3')) is True
    assert os.path.exists(os.path.join(dst_dir, 'multi-dummy004.mp3')) is True

    playlist_name = os.path.basename(str(playlist_current))
    playlist_path = os.path.join(dst_dir, playlist_name)
    assert os.path.exists(playlist_path) is True
    with open(playlist_path, 'r') as f:
        assert '#EXTM3U' == f.readline().rstrip('\n')
        assert '#EXTINF:409,artist - music_name' == f.readline().rstrip(
            '\n')
        assert 'dummy001.mp3' == f.readline().rstrip('\n')
        assert '#EXTINF:281,artist - music_name' == f.readline().rstrip(
            '\n')
        assert 'dummy002.mp3' == f.readline().rstrip('\n')
        assert '#EXTINF:275,artist - music_name' == f.readline().rstrip(
            '\n')
        assert 'あいう えお.mp3' == f.readline().rstrip('\n')
        assert '#EXTINF:263,artist - music_name' == f.readline().rstrip(
            '\n')
        assert 'あいう　えお.mp3' == f.readline().rstrip('\n')
        assert '#EXTINF:288,artist - music_name' == f.readline().rstrip(
            '\n')
        assert 'dummy002.mp3' == f.readline().rstrip('\n')
        assert '' == f.readline().rstrip('\n')

    playlist_name = os.path.basename(str(playlist_current2))
    playlist_path = os.path.join(dst_dir, playlist_name)
    assert os.path.exists(playlist_path) is True
    with open(playlist_path, 'r') as f:
        assert '#EXTM3U' == f.readline().rstrip('\n')
        assert '#EXTINF:409,artist - music_name' == f.readline().rstrip(
            '\n')
        assert 'multi-dummy001.mp3' == f.readline().rstrip('\n')
        assert '#EXTINF:282,artist - music_name' == f.readline().rstrip(
            '\n')
        assert 'multi-dummy001.mp3' == f.readline().rstrip('\n')
        assert '#EXTINF:281,artist - music_name' == f.readline().rstrip(
            '\n')
        assert 'multi-dummy002.mp3' == f.readline().rstrip('\n')
        assert '#EXTINF:275,artist - music_name' == f.readline().rstrip(
            '\n')
        assert 'multi-あいう えお.mp3' == f.readline().rstrip('\n')
        assert '#EXTINF:263,artist - music_name' == f.readline().rstrip(
            '\n')
        assert 'multi-あいう　えお.mp3' == f.readline().rstrip('\n')
        assert '#EXTINF:288,artist - music_name' == f.readline().rstrip(
            '\n')
        assert 'multi-dummy004.mp3' == f.readline().rstrip('\n')
        assert '' == f.readline().rstrip('\n')


# noinspection PyShadowingNames
def test_parse_playlist(playlist_current):
    playlist_path = str(playlist_current)
    files = list(M3uDump.parse_playlist(playlist_path))
    assert files[2] == '/full/path/dummy001.mp3'
    assert files[4] == '/full/path/dummy002.mp3'
    assert files[6] == 'music/あいう えお.mp3'
    assert files[8] == '/full/path/music/あいう　えお.mp3'
    assert len(files) == 13


# noinspection PyShadowingNames
def test_get_search_path_files(music_files):
    search_path_files = M3uDump.get_search_path_files(str(music_files))
    assert 'tmp/music0' in search_path_files['dummy001.mp3'][0]
    assert 'tmp/music0/sub' in search_path_files['dummy002.mp3'][0]
    assert 'tmp/music0/sub2/sub3' in search_path_files['あいう えお.mp3'][0]
    assert 'tmp/music0/sub3/かきく　けこ' in search_path_files['あいう　えお.mp3'][0]
    assert len(search_path_files.keys()) == 11


# noinspection PyShadowingNames
def test_fix_playlist(playlist_current, music_files):
    playlist_path = str(playlist_current)
    files = list(M3uDump.parse_playlist(playlist_path))

    search_path_files = M3uDump.get_search_path_files(str(music_files))

    p = M3uDump.fix_playlist(search_path_files, files)
    assert 'tmp/music0/dummy001.mp3' in p[2]
    assert 'tmp/music0/sub/dummy002.mp3' in p[4]
    assert 'tmp/music0/sub2/sub3/あいう えお.mp3' in p[6]
    assert 'tmp/music0/sub3/かきく　けこ/あいう　えお.mp3' in p[8]
    assert len(p) == 11


# noinspection PyShadowingNames
def test_copy_music_dryrun(playlist_current, music_files, dump_music_path):
    playlist_path = str(playlist_current)
    files = list(M3uDump.parse_playlist(playlist_path))

    search_path_files = M3uDump.get_search_path_files(str(music_files))

    playlist = M3uDump.fix_playlist(search_path_files, files)

    M3uDump.copy_music(playlist, dump_music_path, True)

    assert os.path.exists(
        os.path.join(dump_music_path, 'dummy001.mp3')) is False
    assert os.path.exists(
        os.path.join(dump_music_path, 'dummy002.mp3')) is False
    assert os.path.exists(os.path.join(dump_music_path, 'あいう えお.mp3')) is False
    assert os.path.exists(os.path.join(dump_music_path, 'あいう　えお.mp3')) is False


# noinspection PyShadowingNames
def test_copy_music_nodryrun(playlist_current, music_files, dump_music_path):
    playlist_path = str(playlist_current)
    files = list(M3uDump.parse_playlist(playlist_path))

    search_path_files = M3uDump.get_search_path_files(str(music_files))

    playlist = M3uDump.fix_playlist(search_path_files, files)

    M3uDump.copy_music(playlist, dump_music_path, False)

    assert os.path.exists(os.path.join(dump_music_path, 'dummy001.mp3'))
    assert os.path.exists(os.path.join(dump_music_path, 'dummy002.mp3'))
    assert os.path.exists(os.path.join(dump_music_path, 'あいう えお.mp3'))
    assert os.path.exists(os.path.join(dump_music_path, 'あいう　えお.mp3'))


# noinspection PyShadowingNames
def test_copy_music_override(playlist_current, music_files, dump_music_path):
    playlist_path = str(playlist_current)
    files = list(M3uDump.parse_playlist(playlist_path))

    search_path_files = M3uDump.get_search_path_files(str(music_files))

    playlist = M3uDump.fix_playlist(search_path_files, files)

    M3uDump.copy_music(playlist, dump_music_path, False)
    M3uDump.copy_music(playlist, dump_music_path, False)

    assert os.path.exists(os.path.join(dump_music_path, 'dummy001.mp3'))
    assert os.path.exists(os.path.join(dump_music_path, 'dummy002.mp3'))
    assert os.path.exists(os.path.join(dump_music_path, 'あいう えお.mp3'))
    assert os.path.exists(os.path.join(dump_music_path, 'あいう　えお.mp3'))


# noinspection PyShadowingNames
def test_load_from_playlist_path(playlist_dir, playlist_current2, playlist_current):
    playlist_path = str(playlist_dir)
    allowed_pattern = ['*.m3u', '*.m3u8']
    path_list = M3uDump.load_from_playlist_path(playlist_path, allowed_pattern)

    # os.walk は順序が分からない
    assert 'playlist.m3u' in path_list[0]
    assert 'playlist2.m3u8' in path_list[1]
    assert len(path_list) == 2



# -*- coding: utf-8 -*-

import click

from m3u_dump.m3u_dump import M3uDump


@click.command()
@click.argument('load-m3u-path', type=click.Path(exists=True))
@click.argument('dump-music-path')
@click.option('--dry-run/--no-dry-run', default=False, help='Dry run')
@click.option('--with-playlist/--no-with-playlist', default=True, help='too copy fixed playlist')
@click.option('--fix-search-path', default=None, help='fix search path')
@click.option('--playlist-pattern-list', default=['*.m3u', '*.m3u8'])
def main(**kwargs):
    """Console script for m3u_dump"""

    click.echo(click.style('=' * 53, fg='green'))
    click.echo(click.style('   Welcome m3u-dump!!', fg='green'))
    click.echo(click.style('=' * 53, fg='green'))

    M3uDump(kwargs).start()

    click.echo()
    click.echo(click.style('copy was completed(successful!).'))

if __name__ == "__main__":
    main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
    'Click>=6.0',
]

test_requirements = [
    # TODO: put package test requirements here
]
from setuptools.command.install import install as _install
class install(_install):
    def run(self):
        _install.run(self)
        print('hello')

setup(
    name='m3u_dump',
    version='1.0.1',
    description="m3u dump",
    long_description=readme + '\n\n' + history,
    author="Shuuhei Tateya",
    author_email='stateya@gmail.com',
    url='https://github.com/stateya/m3u-dump',
    packages=[
        'm3u_dump',
    ],
    package_dir={'m3u_dump':
                 'm3u_dump'},
    entry_points={
        'console_scripts': [
            'm3u-dump=m3u_dump.cli:main'
        ]
    },
    include_package_data=True,
    install_requires=requirements,
    license="MIT license",
    zip_safe=False,
    keywords='m3u_dump',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3.5',
    ],
    test_suite='tests',
    cmdclass={'install': install},
    tests_require=test_requirements
)



# -*- coding: utf-8 -*-
import fnmatch
import glob
import logging
import logging.config
import os
import pprint
import shutil

pp = pprint.PrettyPrinter(indent=4)

log = logging.getLogger(__name__)


class M3uDump:
    def __init__(self, args):
        self.args = args

        self.setup_logging()

        log.info('\n' + pp.pformat(self.args))

    @staticmethod
    def setup_logging():
        module_path = os.path.abspath(os.path.dirname(__file__))
        logging.config.fileConfig(os.path.join(module_path, 'logging.conf'))

    @staticmethod
    def parse_playlist(playlist_path):
        log.info('playlist{} reading....'.format(playlist_path))

        def is_not_empty_line(line):
            if len(line) > 0:
                return True
            else:
                return False

        with open(playlist_path, 'r') as f:
            return filter(is_not_empty_line, map(lambda x: x.strip(),
                                                 f.readlines()))

    @staticmethod
    def get_search_path_files(search_path):
        log.info('scanning search_path({0})...'.format(search_path))
        search_path_files = {}
        for (root, dirs, files) in os.walk(search_path):
            for f in files:
                if f in search_path_files:
                    search_path_files[f].append(root)
                else:
                    search_path_files.update({f: [root]})
        return search_path_files

    @staticmethod
    def is_comment(line):
        if line.lstrip().startswith('#EXTINF'):
            return True
        elif line.lstrip().startswith('#EXTM3U'):
            return True
        else:
            return False

    @staticmethod
    def fix_playlist(search_path_files, playlist_lines):
        new_playlist_lines = []

        for i in playlist_lines:
            if M3uDump.is_comment(i):
                new_playlist_lines.append(i)
                continue
            elif os.path.exists(i):
                new_playlist_lines.append(i)
                continue
            basename = os.path.basename(i)
            if basename in search_path_files:
                p = os.path.join(search_path_files[basename][0], basename)
                new_playlist_lines.append(p)
            else:
                log.warning(
                    'skip dump, because music file of {0} was '.format(
                        basename) +
                    'not found in search path.')
                # delete comment
                new_playlist_lines.pop()
        return new_playlist_lines

    @staticmethod
    def copy_music(playlist_lines, dump_music_path, dry_run):
        for i in playlist_lines:
            if M3uDump.is_comment(i):
                continue
            elif os.path.exists(i) is False:
                log.warning(
                    'skip copy, because music file({}) was not found.'.format(
                        i))
                continue

            dst = os.path.join(dump_music_path, os.path.basename(i))
            if dry_run is False:
                log.info('copying {0} -> {1}'.format(i, dst))
                shutil.copyfile(i, dst)
            else:
                log.info('(dryrun)copying {0} -> {1}'.format(i, dst))

    @staticmethod
    def save_playlist(playlist_name, playlist_lines, dump_music_path, dry_run):
        playlist_path = os.path.join(dump_music_path, playlist_name)
        if dry_run is False:
            with open(playlist_path, 'w') as f:
                log.info('writing playlist({})...'.format(playlist_path))
                for i in playlist_lines:
                    if M3uDump.is_comment(i):
                        f.write(i + '\n')
                    else:
                        music_file_name = os.path.basename(i)
                        f.write(music_file_name + '\n')
        else:
            log.info('(dryrun)writing playlist({})...'.format(playlist_path))

    def dump_playlist(self, playlist_path):
        playlist_lines = list(M3uDump.parse_playlist(playlist_path))
        log.debug('playlist_line is follows...')
        show_num = len(playlist_lines) if len(playlist_lines) < 3 else 3
        for i in range(0, show_num):
            log.debug(playlist_lines[i])

        # fix playlist
        if self.args['fix_search_path']:
            search_path_files = M3uDump.get_search_path_files(
                self.args['fix_search_path'])

            playlist_lines = M3uDump.fix_playlist(search_path_files,
                                                  playlist_lines)

        # copy music in playlist
        M3uDump.copy_music(playlist_lines, self.args['dump_music_path'],
                           self.args['dry_run'])

        # dump fixed playlist
        playlist_name = os.path.basename(playlist_path)
        M3uDump.save_playlist(playlist_name, playlist_lines,
                              self.args['dump_music_path'],
                              self.args['dry_run'])

    @staticmethod
    def load_from_playlist_path(load_m3u_path, pattern_list):
        """
        return playlist_path array in playlist directory
        :param pattern_list:
        :param load_m3u_path:
        :return:
        """
        log.info('loading playlist({})...'.format(load_m3u_path))
        log.info('allowed pattern is {}'.format(pattern_list))
        path_list = []
        for (root, dirs, files) in os.walk(load_m3u_path):
            for f in files:
                if any(map(lambda x: fnmatch.fnmatch(f, x), pattern_list)):
                    path_list.append(os.path.join(root, f))
        return sorted(path_list)

    def start(self):
        log.debug('start -----')

        load_m3u_path = self.args['load_m3u_path']
        if os.path.isfile(self.args['load_m3u_path']):
            load_m3u_path = [self.args['load_m3u_path']]
        else:
            load_m3u_path = M3uDump.load_from_playlist_path(
                self.args['load_m3u_path'], self.args['playlist_pattern_list'])

        log.info('playlist is {}'.format(load_m3u_path))
        for i in load_m3u_path:
            self.dump_playlist(i)
        log.info('copy done.')
